@@ -651,7 +651,7 @@ class CopyProperties(DictMixin):
         self.source = kwargs.get('x-ms-copy-source')
         self.status = get_enum_value(kwargs.get('x-ms-copy-status'))
         self.progress = kwargs.get('x-ms-copy-progress')
-        self.completion_time = kwargs.get('x-ms-copy-completion_time')
+        self.completion_time = kwargs.get('x-ms-copy-completion-time')
         self.status_description = kwargs.get('x-ms-copy-status-description')
         self.incremental_copy = kwargs.get('x-ms-incremental-copy')
         self.destination_snapshot = kwargs.get('x-ms-copy-destination-snapshot')
@@ -792,9 +792,8 @@ class AccessPolicy(GenAccessPolicy):
     :param start:
         The time at which the shared access signature becomes valid. If
         omitted, start time for this call is assumed to be the time when the
-        storage service receives the request. Azure will always convert values
-        to UTC. If a date is passed in without timezone info, it is assumed to
-        be UTC.
+        storage service receives the request. The provided datetime will always
+        be interpreted as UTC.
     :type start: ~datetime.datetime or str
     """
     def __init__(self, permission=None, expiry=None, start=None):
@@ -1065,7 +1064,7 @@ class ContainerEncryptionScope(object):
 class DelimitedJsonDialect(DictMixin):
     """Defines the input or output JSON serialization for a blob data query.
 
-    :keyword str delimiter: The line separator character, default value is '\n'
+    :keyword str delimiter: The line separator character, default value is '\\\\n'.
     """
 
     def __init__(self, **kwargs):
