@@ -19,10 +19,6 @@ SOFT_DELETE_STORAGE_ACCOUNT_NAME = "fakename"
 SOFT_DELETE_STORAGE_ACCOUNT_KEY = "fakekey"
 STORAGE_RESOURCE_GROUP_NAME = "fakename"
 
-TENANT_ID = "00000000-0000-0000-0000-000000000000"
-CLIENT_ID = "00000000-0000-0000-0000-000000000000"
-CLIENT_SECRET = "00000000-0000-0000-0000-000000000000"
-
 ACCOUNT_URL_SUFFIX = 'core.windows.net'
 RUN_IN_LIVE = "False"
 SKIP_LIVE_RECORDING = "True"
