@@ -93,7 +93,7 @@ class TestStorageBlockBlob(StorageRecordedTestCase):
         source_blob_data = self.get_random_bytes(LARGE_BLOB_SIZE)
         source_blob_client = self._create_source_blob(data=source_blob_data)
         destination_blob_client = self._create_blob()
-        token = "Bearer {}".format(self.generate_oauth_token().get_token("https://storage.azure.com/.default").token)
+        token = "Bearer {}".format(self.get_credential(BlobServiceClient).get_token("https://storage.azure.com/.default").token)
 
         # Assert this operation fails without a credential
         with pytest.raises(HttpResponseError):
@@ -583,7 +583,7 @@ class TestStorageBlockBlob(StorageRecordedTestCase):
         container_name = self.get_resource_name('vlwcontainer')
 
         if self.is_live:
-            token_credential = self.generate_oauth_token()
+            token_credential = self.get_credential(BlobServiceClient)
             subscription_id = self.get_settings_value("SUBSCRIPTION_ID")
 
             mgmt_client = StorageManagementClient(token_credential, subscription_id, '2021-04-01')
